@@ -30,15 +30,13 @@
 #include <gkbd-config-private.h>
 #include <gkbd-util.h>
 
-/**
+/*
  * GkbdKeyboardConfig
  */
 
 #define GROUP_SWITCHERS_GROUP "grp"
 #define DEFAULT_GROUP_SWITCH "grp:shift_caps_toggle"
 
-#define XMODMAP_CMD "xmodmap"
-
 const gchar GKBD_KEYBOARD_CONFIG_KEY_MODEL[] = "model";
 const gchar GKBD_KEYBOARD_CONFIG_KEY_LAYOUTS[] = "layouts";
 const gchar GKBD_KEYBOARD_CONFIG_KEY_OPTIONS[] = "options";
@@ -49,9 +47,7 @@ const gchar *GKBD_KEYBOARD_CONFIG_ACTIVE[] = {
 	GKBD_KEYBOARD_CONFIG_KEY_OPTIONS
 };
 
-const gchar *XMODMAP_KNOWN_FILES[] = { ".xmodmap", ".Xmodmap" };
-
-/**
+/*
  * static common functions
  */
 
@@ -127,7 +123,7 @@ gkbd_keyboard_config_get_lv_descriptions (XklConfigRegistry *
 	return *layout_descr != NULL;
 }
 
-/**
+/*
  * extern common functions
  */
 const gchar *
@@ -181,7 +177,7 @@ gkbd_keyboard_config_split_items (const gchar * merged, gchar ** parent,
 	return TRUE;
 }
 
-/**
+/*
  * static GkbdKeyboardConfig functions
  */
 
@@ -408,7 +404,7 @@ gkbd_keyboard_config_save_params (GkbdKeyboardConfig * kbd_config,
 	}
 }
 
-/**
+/*
  * extern GkbdKeyboardConfig config functions
  */
 void
@@ -523,15 +519,23 @@ gkbd_keyboard_config_options_equals (GkbdKeyboardConfig * kbd_config1,
 			char *group2, *option2;
 			gboolean are_equal = FALSE;
 
-			if (!gkbd_keyboard_config_split_items (kbd_config1->options[i], &group1, &option1))
+			if (!gkbd_keyboard_config_split_items
+			    (kbd_config1->options[i], &group1, &option1))
 				continue;
 
+			option1 = g_strdup (option1);
+
 			for (j = 0; j < num_options && !are_equal; j++) {
-				if (gkbd_keyboard_config_split_items (kbd_config2->options[j], &group2, &option2)) {
-					are_equal = strcmp (option1, option2) == 0;
+				if (gkbd_keyboard_config_split_items
+				    (kbd_config2->options[j], &group2,
+				     &option2)) {
+					are_equal =
+					    strcmp (option1, option2) == 0;
 				}
 			}
 
+			g_free (option1);
+
 			if (!are_equal)
 				return False;
 		}
@@ -552,10 +556,11 @@ gkbd_keyboard_config_equals (GkbdKeyboardConfig * kbd_config1,
 	    g_ascii_strcasecmp (kbd_config1->model, kbd_config2->model))
 		return False;
 	if (!g_strv_equal (kbd_config1->layouts_variants,
-			     kbd_config2->layouts_variants))
+			   kbd_config2->layouts_variants))
 		return False;
 
-	if (!gkbd_keyboard_config_options_equals (kbd_config1, kbd_config2))
+	if (!gkbd_keyboard_config_options_equals
+	    (kbd_config1, kbd_config2))
 		return False;
 
 	return True;
@@ -625,45 +630,6 @@ gkbd_keyboard_config_activate (GkbdKeyboardConfig * kbd_config)
 	gkbd_keyboard_config_copy_to_xkl_config (kbd_config, data);
 	rv = xkl_config_rec_activate (data, kbd_config->engine);
 	g_object_unref (G_OBJECT (data));
-
-	/* Small bit of extensibility by using xmodmap */
-	if (rv) {
-		int i =
-		    sizeof (XMODMAP_KNOWN_FILES) /
-		    sizeof (XMODMAP_KNOWN_FILES[0]);
-		while (--i >= 0) {
-			gchar *xmodmap_file =
-			    g_build_filename (g_get_home_dir (),
-					      XMODMAP_KNOWN_FILES[i],
-					      NULL);
-			if (g_file_test (xmodmap_file, G_FILE_TEST_EXISTS)) {
-				GError *error = NULL;
-				gchar *command;
-				xkl_debug (150,
-					   "Loading custom xmodmap file %s\n",
-					   xmodmap_file);
-				command =
-				    g_strconcat (XMODMAP_CMD, " ",
-						 xmodmap_file,
-						 NULL);
-				/* Fire and forget - do not care about errors */
-				if (!g_spawn_command_line_async
-				    (command, &error)) {
-					xkl_debug (0,
-						   "Error loading custom xmodmap file: [%s]\n",
-						   error->message);
-					g_error_free (error);
-				}
-				g_free (command);
-
-				/* One file is enough */
-				i = 0;
-			}
-
-			g_free (xmodmap_file);
-		}
-	}
-
 	return rv;
 }
 
@@ -781,6 +747,7 @@ gkbd_keyboard_config_to_string (const GkbdKeyboardConfig * config)
 
 /**
  * gkbd_keyboard_config_add_default_switch_option_if_necessary:
+ *
  * Returns: (transfer full) (array zero-terminated=1): List of options
  */
 gchar **
